@@ -1,6 +1,6 @@
 # gpxviewer
 #
-# Copyright (C) 2016-2020 Sergey Salnikov <salsergey@gmail.com>
+# Copyright (C) 2016-2023 Sergey Salnikov <salsergey@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3
@@ -78,12 +78,18 @@ class ConfigStore(configparser.ConfigParser):
                                  'AbsoluteTime': False,
                                  'UseSystemTheme': False,
                                  'FontSize': 12,
+                                 'BoldFont': False,
+                                 'ItalicFont': False,
                                  'DistanceCoefficient': 1.0,
                                  'ShowDistanceCoefficient': True,
                                  'TimeZoneOffset': 420,
                                  'SortByTime': False,
                                  'ReadNameFromTag': 0,
-                                 'CoordinateFormat': 0},
+                                 'CoordinateFormat': 0,
+                                 'PointsToTrack': False,
+                                 'DeletePoints': False,
+                                 'TracksToPoints': False,
+                                 'DeleteTracks': False},
                 'PointStyle': {'MarkerColorEnabled': True,
                                'MarkerColor': qRgba(255, 0, 0, 200),
                                'MarkerStyleEnabled': True,
@@ -97,6 +103,10 @@ class ConfigStore(configparser.ConfigParser):
                                'CaptionRotation': 90,
                                'CaptionSizeEnabled': True,
                                'CaptionSize': 12,
+                               'CaptionBoldEnabled': True,
+                               'CaptionBold': False,
+                               'CaptionItalicEnabled': True,
+                               'CaptionItalic': False,
                                'SplitLineColorEnabled': True,
                                'SplitLineColor': qRgba(255, 0, 0, 150),
                                'SplitLineStyleEnabled': True,
@@ -131,8 +141,9 @@ class ConfigStore(configparser.ConfigParser):
         return int(self['ProfileStyle'][key])
       elif key in {'ProfileWidth', 'DistanceCoefficient'}:
         return float(self['ProfileStyle'][key])
-      elif key in {'SelectedPointsOnly', 'StartFromZero', 'AutoscaleAltitudes', 'ShowHours',
-                   'AbsoluteTime', 'UseSystemTheme', 'ShowDistanceCoefficient', 'SortByTime'}:
+      elif key in {'SelectedPointsOnly', 'StartFromZero', 'AutoscaleAltitudes', 'ShowHours', 'AbsoluteTime',
+                   'BoldFont', 'ItalicFont', 'UseSystemTheme', 'ShowDistanceCoefficient', 'SortByTime',
+                   'PointsToTrack', 'DeletePoints', 'TracksToPoints', 'DeleteTracks'}:
         return self['ProfileStyle'].getboolean(key)
       else:
         return self['ProfileStyle'][key]
@@ -145,6 +156,7 @@ class ConfigStore(configparser.ConfigParser):
         return float(self['PointStyle'][key])
       elif key in {'MarkerColorEnabled', 'MarkerStyleEnabled', 'MarkerSizeEnabled',
                    'CaptionPositionEnabled', 'CaptionRotationEnabled', 'CaptionSizeEnabled',
+                   'CaptionBoldEnabled', 'CaptionBold', 'CaptionItalicEnabled', 'CaptionItalic',
                    'SplitLineColorEnabled', 'SplitLineStyleEnabled', 'SplitLineWidthEnabled'}:
         return self['PointStyle'].getboolean(key)
       else:
