@@ -1,6 +1,6 @@
 # gpxviewer
 #
-# Copyright (C) 2016-2020 Sergey Salnikov <salsergey@gmail.com>
+# Copyright (C) 2016-2023 Sergey Salnikov <salsergey@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3
@@ -51,12 +51,18 @@ class SettingsDialog(QDialog):
     self.ui.useSystemThemeCheckBox.setChecked(self.settings['UseSystemTheme'])
     self.ui.fontFamilyBox.setCurrentText(self.settings['FontFamily'])
     self.ui.fontSizeSpinBox.setValue(self.settings['FontSize'])
+    self.ui.boldFontCheckBox.setChecked(self.settings['BoldFont'])
+    self.ui.italicFontCheckBox.setChecked(self.settings['ItalicFont'])
     self.ui.distanceCoeffSpinBox.setValue(self.settings['DistanceCoefficient'])
     self.ui.showCoefficientCheckBox.setChecked(self.settings['ShowDistanceCoefficient'])
     self.ui.timezoneSpinBox.setValue(self.settings['TimeZoneOffset'])
     self.ui.sortByTimeCheckBox.setChecked(self.settings['SortByTime'])
     self.ui.nameTagBox.setCurrentIndex(self.settings['ReadNameFromTag'])
     self.ui.coordinateBox.setCurrentIndex(self.settings['CoordinateFormat'])
+    self.ui.pointsToTrackCheckBox.setChecked(self.settings['PointsToTrack'])
+    self.ui.deletePointsCheckBox.setChecked(self.settings['DeletePoints'])
+    self.ui.tracksToPointsCheckBox.setChecked(self.settings['TracksToPoints'])
+    self.ui.deleteTracksCheckBox.setChecked(self.settings['DeleteTracks'])
 
     self.ui.startFromZeroCheckBox.setEnabled(self.settings['SelectedPointsOnly'])
     self.ui.startFromZeroLabel.setEnabled(self.settings['SelectedPointsOnly'])
@@ -76,12 +82,18 @@ class SettingsDialog(QDialog):
     self.ui.useSystemThemeCheckBox.toggled[bool].connect(self.setUseSystemTheme)
     self.ui.fontFamilyBox.currentTextChanged.connect(self.setFontFamily)
     self.ui.fontSizeSpinBox.valueChanged.connect(self.setFontSize)
+    self.ui.boldFontCheckBox.toggled[bool].connect(self.setBoldFont)
+    self.ui.italicFontCheckBox.toggled[bool].connect(self.setItalicFont)
     self.ui.distanceCoeffSpinBox.valueChanged.connect(self.setDistanceCoefficient)
     self.ui.showCoefficientCheckBox.toggled[bool].connect(self.setShowDistanceCoefficient)
     self.ui.timezoneSpinBox.valueChanged.connect(self.setTimeZoneOffset)
     self.ui.sortByTimeCheckBox.toggled[bool].connect(self.setSortByTime)
     self.ui.nameTagBox.currentIndexChanged.connect(self.setNameTag)
     self.ui.coordinateBox.currentIndexChanged.connect(self.setCoordinateFormat)
+    self.ui.pointsToTrackCheckBox.toggled[bool].connect(self.setPointsToTrack)
+    self.ui.deletePointsCheckBox.toggled[bool].connect(self.setDeletePoints)
+    self.ui.tracksToPointsCheckBox.toggled[bool].connect(self.setTracksToPoints)
+    self.ui.deleteTracksCheckBox.toggled[bool].connect(self.setDeleteTracks)
 
   def accept(self):
     super(SettingsDialog, self).accept()
@@ -145,6 +157,14 @@ class SettingsDialog(QDialog):
   def setFontSize(self):
     self.settings['FontSize'] = self.ui.fontSizeSpinBox.value()
 
+  @pyqtSlot(bool)
+  def setBoldFont(self, enabled):
+    self.settings['BoldFont'] = enabled
+
+  @pyqtSlot(bool)
+  def setItalicFont(self, enabled):
+    self.settings['ItalicFont'] = enabled
+
   @pyqtSlot()
   def setDistanceCoefficient(self):
     self.settings['DistanceCoefficient'] = round(self.ui.distanceCoeffSpinBox.value(), self.ui.distanceCoeffSpinBox.decimals())
@@ -170,3 +190,19 @@ class SettingsDialog(QDialog):
   @pyqtSlot()
   def setCoordinateFormat(self):
     self.settings['CoordinateFormat'] = self.ui.coordinateBox.currentIndex()
+
+  @pyqtSlot(bool)
+  def setPointsToTrack(self, enabled):
+    self.settings['PointsToTrack'] = enabled
+
+  @pyqtSlot(bool)
+  def setDeletePoints(self, enabled):
+    self.settings['DeletePoints'] = enabled
+
+  @pyqtSlot(bool)
+  def setTracksToPoints(self, enabled):
+    self.settings['TracksToPoints'] = enabled
+
+  @pyqtSlot(bool)
+  def setDeleteTracks(self, enabled):
+    self.settings['DeleteTracks'] = enabled
